Error

Struct Error 

pub struct Error<I>(/* private fields */);

Implementations

Source

impl<E> Error<E>

pub fn is_timeout(&self) -> bool

Returns true if a read from the sensor timed out.

pub fn is_io(&self) -> bool

Returns true if an IO error occurred while reading from or writing to the sensor’s data pin.

pub fn is_checksum(&self) -> bool

Returns true if the reading from the sensor had a bad checksum.

pub fn into_io(self) -> Option<E>

If the error was caused by an underlying pin IO error, returns it.