pub struct Error<I>(/* private fields */);Implementations
Sourceimpl<E> Error<E>
impl<E> Error<E>
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if a read from the sensor timed out.
Sourcepub fn is_io(&self) -> bool
pub fn is_io(&self) -> bool
Returns true if an IO error occurred while reading from or writing to
the sensor’s data pin.
Sourcepub fn is_checksum(&self) -> bool
pub fn is_checksum(&self) -> bool
Returns true if the reading from the sensor had a bad checksum.